<?php

namespace App\Exports;

use App\Models\TvSellData;
use App\Models\TvEmiData;
use App\Models\TvSystemEmiData;
use DateTime;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use Illuminate\Support\Facades\Auth;

class SalesReportExport implements FromCollection, WithHeadings, WithMapping,WithStyles
{
    /**
    * @return \Illuminate\Support\Collection
    */

    protected $filter;

    public function __construct($filter)
    {
        $this->filter = $filter;
    }

    public function collection()
    {
        return $this->getSalesData($this->filter);
    }

    private function getSalesData($filter)
    {
        $query = TvSellData::where('user_id', Auth::user()->id);

        switch ($filter) {
            case 'today':
                $query->whereDate('created_at', today());
                break;
            case 'this_month':
                $query->whereMonth('created_at', now()->month);
                break;
            case 'last_six_months':
                $query->whereBetween('created_at', [now()->subMonths(5), now()]);
                break;
            case 'this_year':
                $query->whereYear('created_at', now()->year);
                break;
            default:
                break;
        }

        $tvSellData = $query->latest()->get();

        foreach ($tvSellData as $data) {
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();
            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;

            foreach ($records as $record) {
                $totalAmount += (int) $record->amount;
            }

            $data->total = $totalAmount;
            $data->system = $tvSystemEmiData;

            if ($lastRecord) {
                $data->pin = $lastRecord->pin_code;
                $data->date = $lastRecord->pay_date;

                $lastPayDate = new DateTime($lastRecord->pay_date);
                $nextPayDate = $lastPayDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            } else {
                $createdAtDate = new DateTime($data->created_at);
                $nextPayDate = $createdAtDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            }
        }

        return $tvSellData;
    }

    public function headings(): array
    {
        return [
            'Customer ID',
            'Name',
            'Phone',
            'Barcode',
            'Sale Price',
            'Type',
            'Paid Amount',
            'Payment Due',
            'next Pay Date',
        ];
    }

    public function map($data): array
    {
        return [
            $data->id,
            $data->customer_name,
            $data->customer_phone,
            $data->barcode,
            $data->total_amount,
            $data->duration ==0 ? 'Cash' : 'Emi',
            $data->total,
            $data->total_amount - $data->total,
            $data->next_pay_date,
        ];
    }

    public function styles(Worksheet $sheet)
    {
        return [
            // Style the first row as bold and with a background color
            1    => [
                'font' => [
                    'bold' => true,
                ],
                'fill' => [
                    'fillType'   => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                    'startColor' => [
                        'argb' => 'FFFFE0B2',
                    ],
                ],
            ],
            // Style all rows with a border
            'A1:I' . ($sheet->getHighestRow()) => [
                'borders' => [
                    'allBorders' => [
                        'borderStyle' => \PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN,
                        'color' => ['argb' => 'FF000000'],
                    ],
                ],
            ],
        ];
    }


}
