<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\TvSellData;
use App\Models\RepairTv;
use App\Models\TvSystemEmiData;
use App\Models\TvEmiData;
use Session;
use Auth;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;
use DateTime;


class AdminController extends Controller
{
    //
    public function adminLoginForm(){
        return view('backend.admin.admin_login');
    }

    public function adminLogin(Request $request){
        $request->validate([
            'email' => 'required',
            'password' => 'required'
        ]);
        
         // Check if a regular user is logged in and log them out
        if (Auth::guard('web')->check()) {
            Auth::guard('web')->logout();
        }

        if(Auth::guard('admin')->attempt(['email'=>$request->email,'password'=>$request->password])){
           return redirect('/admin/dashboard');
        }else{
            Session::flash('error-msg','Invalid Email or Password');
            return redirect()->back();
        }

    }


    public function plaza(){
        $users = User::all();
        return view('backend.dashboard.plaza',compact('users'));
    }

    public function plazaDetails(Request $request,$id){
        
        $user = User::where('id',$id)->first();

         $today = Carbon::today();
        $thirtyDaysAgo = $today->copy()->subDays(30);

        $salesData = TvSellData::select(
            DB::raw('DATE(created_at) as date'),
            DB::raw('SUM(CASE WHEN duration = 0 THEN 1 ELSE 0 END) as cash_sales'),
            DB::raw('SUM(CASE WHEN duration != 0 THEN 1 ELSE 0 END) as emi_sales')
        )
        ->where('user_id', $id)
        ->whereBetween('created_at', [$thirtyDaysAgo, $today])
        ->groupBy(DB::raw('DATE(created_at)'))
        ->orderBy('date', 'asc')
        ->get();

       

          // Get cash sales
            $cashSales = DB::table('tv_sell_data')
                ->select(
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('SUM(total_amount) as cash_amount')
                )
                ->where('user_id', $id)
                ->where('duration', 0)
                ->whereBetween('created_at', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(created_at)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Get down payments
            $downPayments = DB::table('tv_sell_data')
                ->select(
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('SUM(down_payment) as down_amount')
                )
                ->where('user_id', $id)
                ->where('duration', '!=', 0)
                ->whereBetween('created_at', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(created_at)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Get EMI amounts
            $emiAmounts = DB::table('tv_emi_data')
                ->join('tv_sell_data', 'tv_emi_data.sell_id', '=', 'tv_sell_data.id')
                ->select(
                    DB::raw('DATE(tv_emi_data.pay_date) as date'),
                    DB::raw('SUM(tv_emi_data.amount) as emi_amount')
                )
                ->where('tv_sell_data.user_id', $id)
                ->where('tv_sell_data.duration', '!=', 0)
                ->whereBetween('tv_emi_data.pay_date', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(tv_emi_data.pay_date)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Combine data into a single array
            $combinedData = [];
        
            foreach ($cashSales as $cash) {
                $combinedData[$cash->date] = [
                    'date' => $cash->date,
                    'cash_amount' => $cash->cash_amount,
                    'down_amount' => 0,
                    'emi_amount' => 0
                ];
            }
        
            foreach ($downPayments as $down) {
                if (isset($combinedData[$down->date])) {
                    $combinedData[$down->date]['down_amount'] = $down->down_amount;
                } else {
                    $combinedData[$down->date] = [
                        'date' => $down->date,
                        'cash_amount' => 0,
                        'down_amount' => $down->down_amount,
                        'emi_amount' => 0
                    ];
                }
            }
        
            foreach ($emiAmounts as $emi) {
                if (isset($combinedData[$emi->date])) {
                    $combinedData[$emi->date]['emi_amount'] = $emi->emi_amount;
                } else {
                    $combinedData[$emi->date] = [
                        'date' => $emi->date,
                        'cash_amount' => 0,
                        'down_amount' => 0,
                        'emi_amount' => $emi->emi_amount
                    ];
                }
            }
        
            // Sort by date
            ksort($combinedData);
            
            
                    
            // Get all sales data for the last 30 days
            $salesData1 = DB::table('tv_sell_data')
                ->select(
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('SUM(total_amount) as total_amount'),
                    DB::raw('SUM(down_payment) as down_payment')
                )
                ->where('user_id', $id)
                ->whereBetween('created_at', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(created_at)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Get all EMI data for the last 30 days
            $emiData1 = DB::table('tv_emi_data')
                ->join('tv_sell_data', 'tv_emi_data.sell_id', '=', 'tv_sell_data.id')
                ->select(
                    DB::raw('DATE(tv_emi_data.pay_date) as date'),
                    DB::raw('SUM(tv_emi_data.amount) as emi_amount')
                )
                ->where('tv_sell_data.user_id', $id)
                ->whereBetween('tv_emi_data.pay_date', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(tv_emi_data.pay_date)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Combine data into a single array
            $combinedData1 = [];
        
            foreach ($salesData1 as $sale1) {
                $combinedData1[$sale1->date] = [
                    'date' => $sale1->date,
                    'total_amount' => $sale1->total_amount,
                    'down_payment' => $sale1->down_payment,
                    'emi_amount' => 0
                ];
            }
        
            foreach ($emiData1 as $emi1) {
                if (isset($combinedData1[$emi1->date])) {
                    $combinedData1[$emi1->date]['emi_amount'] = $emi1->emi_amount;
                } else {
                    $combinedData1[$emi1->date] = [
                        'date' => $emi1->date,
                        'total_amount' => 0,
                        'down_payment' => 0,
                        'emi_amount' => $emi1->emi_amount
                    ];
                }
            }
        
            // Sort by date and calculate cumulative sums
            ksort($combinedData1);
        
            $cumulativeTotalAmount = 0;
            $cumulativeMoneyCollection = 0;
            $cumulativeCredit = 0;
            
        
            foreach ($combinedData1 as &$data) {
                $cumulativeTotalAmount += $data['total_amount'];
                $cumulativeMoneyCollection += $data['down_payment'] + $data['emi_amount'];
                $cumulativeCredit += $data['total_amount'] - ($data['down_payment'] + $data['emi_amount']);
        
                $data['cumulative_total_amount'] = $cumulativeTotalAmount;
                $data['cumulative_money_collection'] = $cumulativeMoneyCollection;
                $data['cumulative_credit'] = $cumulativeCredit;
            }


        $totalCashSalesCount = DB::table('tv_sell_data')
        ->where('user_id', $id)
        ->where('duration', 0)
        ->count();
    
        // Get today's cash sales count
        $todayCashSalesCount = DB::table('tv_sell_data')
            ->where('user_id', $id)
            ->where('duration', 0)
            ->whereDate('created_at', $today)
            ->count();
    
        // Get total installment sales count
        $totalInstallmentSalesCount = DB::table('tv_sell_data')
            ->where('user_id', $id)
            ->where('duration', '>', 0)
            ->count();
    
        // Get today's installment sales count
        $todayInstallmentSalesCount = DB::table('tv_sell_data')
            ->where('user_id', $id)
            ->where('duration', '>', 0)
            ->whereDate('created_at', $today)
            ->count();
    
        // Calculate overall totals
        $totalOverallSalesCount = $totalCashSalesCount + $totalInstallmentSalesCount;
        $todayOverallSalesCount = $todayCashSalesCount + $todayInstallmentSalesCount;
    
        $totals = [
            'cash_total' => $totalCashSalesCount,
            'cash_today' => $todayCashSalesCount,
            'emi_total' => $totalInstallmentSalesCount,
            'emi_today' => $todayInstallmentSalesCount,
            'overall_today' => $todayOverallSalesCount,
            'overall_total' => $totalOverallSalesCount
        ];
        
        
        
        $query = TvSellData::where('user_id', $id);

        
        $tvSellData = $query->latest()->get();

        foreach ($tvSellData as $data) {
            
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();

            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;
   
            foreach ($records as $record) {
            
                $totalAmount += (int) $record->amount;
            }
            $data->total = $totalAmount; 
            $data->system = $tvSystemEmiData;
           

            if($lastRecord){
                 $data->pin = $lastRecord->pin_code;
                 $data->date = $lastRecord->pay_date;

                $lastPayDate = new DateTime($lastRecord->pay_date);

                $nextPayDate = $lastPayDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');

            }else{
                
                $createdAtDate = new DateTime($data->created_at);

                $nextPayDate = $createdAtDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            }   
        }

         $tvDueSellData = TvSellData::where('user_id', $id)->get();

        foreach ($tvDueSellData as $key => $data) {
            
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();
            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;

            foreach ($records as $record) {
                $totalAmount += (int) $record->amount;
            }
            $data->total = $totalAmount; 
            $data->system = $tvSystemEmiData;
           
            if ($lastRecord) {
                $data->pin = $lastRecord->pin_code;
                $data->date = $lastRecord->pay_date;
            }


            if ($lastRecord && Carbon::parse($lastRecord->pay_date)->greaterThan(Carbon::now()->subMonth())) {
            
                unset($tvDueSellData[$key]);
            } 

            if(!isset($lastRecord->pay_date) &&  Carbon::parse($data->createdAt)->greaterThan(Carbon::now()->subMonth())){
                unset($tvDueSellData[$key]);
            }


        }




        return view('backend.dashboard.plaza_detail',compact('salesData','combinedData','combinedData1','totals','tvSellData','tvDueSellData','user'));

    }

    public function paymentAdminHistory(Request $request,$barcode){
        $records = TvEmiData::where('barcode', $barcode)->get();
      
        return view("backend.dashboard.payment",compact('records'));
    }


    

}
