<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Models\TvSellData;
use App\Models\TvEmiData;
use App\Models\TvSystemEmiData;
use App\Models\Tvdata;
use App\Models\RepairTv;
use App\Models\TvOldData;
use App\Models\TvOldEmiData;
use App\Models\ProductionTvData;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Hash;
use DateTime;
use Barryvdh\DomPDF\Facade\Pdf;
use App\Exports\SalesReportExport;
use Maatwebsite\Excel\Facades\Excel;



class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        
        $today = Carbon::today();
        $thirtyDaysAgo = $today->copy()->subDays(30);

        $salesData = TvSellData::select(
            DB::raw('DATE(created_at) as date'),
            DB::raw('SUM(CASE WHEN duration = 0 THEN 1 ELSE 0 END) as cash_sales'),
            DB::raw('SUM(CASE WHEN duration != 0 THEN 1 ELSE 0 END) as emi_sales')
        )
        ->where('user_id', Auth::user()->id)
        ->whereBetween('created_at', [$thirtyDaysAgo, $today])
        ->groupBy(DB::raw('DATE(created_at)'))
        ->orderBy('date', 'asc')
        ->get();

       

          // Get cash sales
            $cashSales = DB::table('tv_sell_data')
                ->select(
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('SUM(total_amount) as cash_amount')
                )
                ->where('user_id', Auth::user()->id)
                ->where('duration', 0)
                ->whereBetween('created_at', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(created_at)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Get down payments
            $downPayments = DB::table('tv_sell_data')
                ->select(
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('SUM(down_payment) as down_amount')
                )
                ->where('user_id', Auth::user()->id)
                ->where('duration', '!=', 0)
                ->whereBetween('created_at', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(created_at)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Get EMI amounts
            $emiAmounts = DB::table('tv_emi_data')
                ->join('tv_sell_data', 'tv_emi_data.sell_id', '=', 'tv_sell_data.id')
                ->select(
                    DB::raw('DATE(tv_emi_data.pay_date) as date'),
                    DB::raw('SUM(tv_emi_data.amount) as emi_amount')
                )
                ->where('tv_sell_data.user_id', Auth::user()->id)
                ->where('tv_sell_data.duration', '!=', 0)
                ->whereBetween('tv_emi_data.pay_date', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(tv_emi_data.pay_date)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Combine data into a single array
            $combinedData = [];
        
            foreach ($cashSales as $cash) {
                $combinedData[$cash->date] = [
                    'date' => $cash->date,
                    'cash_amount' => $cash->cash_amount,
                    'down_amount' => 0,
                    'emi_amount' => 0
                ];
            }
        
            foreach ($downPayments as $down) {
                if (isset($combinedData[$down->date])) {
                    $combinedData[$down->date]['down_amount'] = $down->down_amount;
                } else {
                    $combinedData[$down->date] = [
                        'date' => $down->date,
                        'cash_amount' => 0,
                        'down_amount' => $down->down_amount,
                        'emi_amount' => 0
                    ];
                }
            }
        
            foreach ($emiAmounts as $emi) {
                if (isset($combinedData[$emi->date])) {
                    $combinedData[$emi->date]['emi_amount'] = $emi->emi_amount;
                } else {
                    $combinedData[$emi->date] = [
                        'date' => $emi->date,
                        'cash_amount' => 0,
                        'down_amount' => 0,
                        'emi_amount' => $emi->emi_amount
                    ];
                }
            }
        
            // Sort by date
            ksort($combinedData);
            
            
                    
            // Get all sales data for the last 30 days
            $salesData1 = DB::table('tv_sell_data')
                ->select(
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('SUM(total_amount) as total_amount'),
                    DB::raw('SUM(down_payment) as down_payment')
                )
                ->where('user_id', Auth::user()->id)
                ->whereBetween('created_at', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(created_at)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Get all EMI data for the last 30 days
            $emiData1 = DB::table('tv_emi_data')
                ->join('tv_sell_data', 'tv_emi_data.sell_id', '=', 'tv_sell_data.id')
                ->select(
                    DB::raw('DATE(tv_emi_data.pay_date) as date'),
                    DB::raw('SUM(tv_emi_data.amount) as emi_amount')
                )
                ->where('tv_sell_data.user_id', Auth::user()->id)
                ->whereBetween('tv_emi_data.pay_date', [$thirtyDaysAgo, $today])
                ->groupBy(DB::raw('DATE(tv_emi_data.pay_date)'))
                ->orderBy('date', 'asc')
                ->get();
        
            // Combine data into a single array
            $combinedData1 = [];
        
            foreach ($salesData1 as $sale1) {
                $combinedData1[$sale1->date] = [
                    'date' => $sale1->date,
                    'total_amount' => $sale1->total_amount,
                    'down_payment' => $sale1->down_payment,
                    'emi_amount' => 0
                ];
            }
        
            foreach ($emiData1 as $emi1) {
                if (isset($combinedData1[$emi1->date])) {
                    $combinedData1[$emi1->date]['emi_amount'] = $emi1->emi_amount;
                } else {
                    $combinedData1[$emi1->date] = [
                        'date' => $emi1->date,
                        'total_amount' => 0,
                        'down_payment' => 0,
                        'emi_amount' => $emi1->emi_amount
                    ];
                }
            }
        
            // Sort by date and calculate cumulative sums
            ksort($combinedData1);
        
            $cumulativeTotalAmount = 0;
            $cumulativeMoneyCollection = 0;
            $cumulativeCredit = 0;
            
        
            foreach ($combinedData1 as &$data) {
                $cumulativeTotalAmount += $data['total_amount'];
                $cumulativeMoneyCollection += $data['down_payment'] + $data['emi_amount'];
                $cumulativeCredit += $data['total_amount'] - ($data['down_payment'] + $data['emi_amount']);
        
                $data['cumulative_total_amount'] = $cumulativeTotalAmount;
                $data['cumulative_money_collection'] = $cumulativeMoneyCollection;
                $data['cumulative_credit'] = $cumulativeCredit;
            }


        $totalCashSalesCount = DB::table('tv_sell_data')
        ->where('user_id', Auth::user()->id)
        ->where('duration', 0)
        ->count();
    
        // Get today's cash sales count
        $todayCashSalesCount = DB::table('tv_sell_data')
            ->where('user_id', Auth::user()->id)
            ->where('duration', 0)
            ->whereDate('created_at', $today)
            ->count();
    
        // Get total installment sales count
        $totalInstallmentSalesCount = DB::table('tv_sell_data')
            ->where('user_id', Auth::user()->id)
            ->where('duration', '>', 0)
            ->count();
    
        // Get today's installment sales count
        $todayInstallmentSalesCount = DB::table('tv_sell_data')
            ->where('user_id', Auth::user()->id)
            ->where('duration', '>', 0)
            ->whereDate('created_at', $today)
            ->count();
    
        // Calculate overall totals
        $totalOverallSalesCount = $totalCashSalesCount + $totalInstallmentSalesCount;
        $todayOverallSalesCount = $todayCashSalesCount + $todayInstallmentSalesCount;
    
        $totals = [
            'cash_total' => $totalCashSalesCount,
            'cash_today' => $todayCashSalesCount,
            'emi_total' => $totalInstallmentSalesCount,
            'emi_today' => $todayInstallmentSalesCount,
            'overall_today' => $todayOverallSalesCount,
            'overall_total' => $totalOverallSalesCount
        ];



        return view('seller.home',compact('salesData','combinedData','combinedData1','totals'));
    }
    
    
     public function showChangePasswordForm()
    {
        return view('seller.reset');
    }
    
    public function changePassword(Request $request)
    {
        // Validate the request
        $request->validate([
            'current_password' => 'required',
            'new_password' => 'required|min:8|confirmed',  // Ensure new password and confirm password match
        ]);
    
        // Find the authenticated user
        $user = auth()->user();
    
        // Check if the current password is correct
        if (!Hash::check($request->current_password, $user->password)) {
            return back()->withErrors(['current_password' => 'Current password is incorrect']);
        }
    
        // Hash the new password and update it
        $user->password = Hash::make($request->new_password);
        $user->save();
    
        return back()->with('success', 'Password updated successfully');
    }
    

    public function search(Request $request)
    {
       
    
        // Extract validated query and searchBy
        $query = $request->query->get('query');
        $searchBy = $request->query->get('searchBy');
        
        if($searchBy == "pass_key"){
            $tvSystem = TvSystemEmiData::where('passkeys','LIKE',"%{$query}%")->first();
            $query = $tvSystem->barcode;
            $searchBy='barcode';
            
        }
       
        // Fetch data based on the validated input
        $tvSellData = TvSellData::where($searchBy, 'LIKE', "%{$query}%")
                                 ->where('user_id', Auth::user()->id)
                                 ->get();
        
        
        foreach ($tvSellData as $data) {
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();
    
            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;
    
            foreach ($records as $record) {
                $totalAmount += (int) $record->amount;
            }
    
            $data->total = $totalAmount;
            $data->system = $tvSystemEmiData;
            $data->records = $records;
    
            if ($lastRecord) {
                $data->pin = $lastRecord->pin_code;
                $data->date = $lastRecord->pay_date;
    
                $lastPayDate = new DateTime($lastRecord->pay_date);
                $nextPayDate = $lastPayDate->modify('+1 month');
    
                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            } else {
                $createdAtDate = new DateTime($data->created_at);
                $nextPayDate = $createdAtDate->modify('+1 month');
    
                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            }
        }
    
        return view('seller.search_result', compact('tvSellData'));
    }
    
    
    

    public function newTv(){
        return view('seller.tvinfo');
    }

    public function barcodeCheck($barcode = null){
        return view('seller.barcode',compact('barcode'));
    }


    public function sellRecords(Request $request){
        $query = TvSellData::where('user_id', Auth::user()->id);

        if ($request->has('filter')) {
            switch ($request->filter) {
                case 'today':
                    $query->whereDate('created_at', today());
                    break;
                case 'this_month':
                    $query->whereMonth('created_at', now()->month);
                    break;
                case 'last_six_months':
                    $query->whereBetween('created_at', [now()->subMonths(5), now()]);
                    break;
                case 'this_year':
                    $query->whereYear('created_at', now()->year);
                    break;
                case 'custom_range':
                    $query->whereBetween('created_at', [$request->start_date, $request->end_date]);
                    break;
                case 'all_record':
                    break;
                default:
                    $query->whereDate('created_at', today());
                    break;
            }
        }
    
        $tvSellData = $query->latest()->get();

        foreach ($tvSellData as $data) {
            
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();

            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;
   
            foreach ($records as $record) {
            
                $totalAmount += (int) $record->amount;
            }
            $data->total = $totalAmount; 
            $data->system = $tvSystemEmiData;
            
            if($lastRecord){
                 $data->pin = $lastRecord->pin_code;
                 $data->date = $lastRecord->pay_date;

                $lastPayDate = new DateTime($lastRecord->pay_date);

                $nextPayDate = $lastPayDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');

            }else{
                
                $createdAtDate = new DateTime($data->created_at);

                $nextPayDate = $createdAtDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            }
            
            
                        
        }

        return view('seller.records',compact('tvSellData'));
    }

    public function dueSellRecords(Request $request)
{
    // Base query
    $query = TvSellData::where('user_id', Auth::user()->id);

    // Apply filters based on the request
    if ($request->has('filter')) {
        switch ($request->filter) {
            case 'today':
                $query->whereDate('created_at', today());
                break;
            case 'this_month':
                $query->whereMonth('created_at', now()->month);
                break;
            case 'last_six_months':
                $query->whereBetween('created_at', [now()->subMonths(5), now()]);
                break;
            case 'this_year':
                $query->whereYear('created_at', now()->year);
                break;
            case 'custom_range':
                $query->whereBetween('created_at', [$request->start_date, $request->end_date]);
                break;
            case 'all_record':
                // No additional filter
                break;
            default:
                $query->whereDate('created_at', today());
                break;
        }
    }

        // Fetch and process the data
        $tvSellData = $query->latest()->get()->map(function ($data) {
            
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();
            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;
    
            foreach ($records as $record) {
                $totalAmount += (int) $record->amount;
            }
    
            $data->total = $totalAmount;
            $data->system = $tvSystemEmiData;
    
            if ($lastRecord) {
                $data->pin = $lastRecord->pin_code;
                $data->date = $lastRecord->pay_date;
            }
    
            return $data;
        });
        
        // Filter out records based on the payment date logic
        $tvSellData = $tvSellData->filter(function ($data) {
            $lastRecord = TvEmiData::where('barcode', $data->barcode)->latest()->first();
            
            // Exclude records if the last payment was within the last month
            if ($lastRecord && Carbon::parse($lastRecord->pay_date)->greaterThan(Carbon::now()->subMonth())) {
                return false;
            }
            
            // Exclude records with no payment and less than a month old
            if (!$lastRecord && Carbon::parse($data->created_at)->greaterThan(Carbon::now()->subMonth())) {
                return false;
            }
            
            return true;
        });
        
       return view('seller.due_records', compact('tvSellData'));
}



    public function regularPayment($barcode = null){
       
        return view('seller.regular_payment',compact('barcode'));
    }

    public function regularBarcodeCheck(Request $request){
        $validatedData = $request->validate([
            'barcode' => 'required|string',
        ]);

        $existingRecord = TvSellData::where('user_id', Auth::user()->id)
        ->where('barcode', $validatedData['barcode'])
        ->exists();

        if ($existingRecord) {
            
            $systemData = TvSystemEmiData::where('barcode', $validatedData['barcode'])->first();
           
                $barcode = "";

                $tvSellData = TvSellData::where('barcode', $validatedData['barcode'])->first();
                $barcode = $validatedData['barcode'];
                       
                $records = TvEmiData::where('barcode', $barcode)->get();
                
                $totalAmount = $tvSellData->down_payment;

                foreach ($records as $record) {
                    
                    $totalAmount += (int) $record->amount;
                }
                
                return redirect()->back()->with('success', 'Secure codes generated successfully.')
                                            ->with('tvSellData', $tvSellData)                               
                                            ->with('records', $records)
                                            ->with('totalAmount', $totalAmount)
                                            ->with('due',(int) $tvSellData->total_amount - $totalAmount);
           
        }   
        else{
                return redirect()->back()->with('error', 'You are not authorized to generate Pin code for this Barcode');
            }
    }


    public function sellTvData(Request $request)  {
         
          $validatedData = $request->validate([
            'customer_name' => 'required|string|max:255',
            'customer_phone' => 'required|string|max:20',
            'customer_nid' => 'required|string|max:255',
            'security_code' => 'required|string|max:255',
            'selected_value' => 'required',
            'barcode' => 'required|string|max:255',
            'selling_price' => 'required|numeric',
            'initial_payment' => 'required|numeric',
            'duration' => 'required|not_in:Select Duration|string',
            'address'=>'required'
        ]);

        $validatedData['barcode'] = $validatedData['selected_value']. $validatedData['barcode'];
        
       try{
           $tvSystemEmiData = TvSystemEmiData::where('barcode', $validatedData['barcode'])->first();

        if($tvSystemEmiData){

            $tvSellInfo =TvSellData::where('barcode', $validatedData['barcode'])->first();
            if($tvSellInfo){
                return redirect()->back()->with('error', 'This TV already sold out'); 
            }
            
            
            $tvprod = ProductionTvData::where('barcode', $validatedData['barcode'])->first();
        
            if($validatedData['security_code'] != $tvprod->security_code ){
                 return redirect()->back()->with('error', 'Invalid security code'); 
            }
            
            
            if($validatedData['selling_price'] == $validatedData['initial_payment']){
                $validatedData['duration'] = 0;
            }
            
            
            try {
                DB::beginTransaction();
            
                $tvSellData = new TvSellData();
                $tvSellData->user_id = Auth::user()->id;
                $tvSellData->customer_name = $validatedData['customer_name'];
                $tvSellData->customer_phone = $validatedData['customer_phone'];
                $tvSellData->nid = $validatedData['customer_nid'];
                $tvSellData->barcode = $validatedData['barcode'];
                $tvSellData->total_amount = $validatedData['selling_price'];
                $tvSellData->down_payment = $validatedData['initial_payment'];
                $tvSellData->duration = $validatedData['duration'];
                $tvSellData->address = $validatedData['address'];
                $tvSellData->save();
            
                $tvSellDataId = $tvSellData->id;
            
                $tvNewData = new Tvdata();
                $tvNewData->mac_address = $tvSystemEmiData->mac;
                $tvNewData->barcode = $validatedData['barcode'];
                $tvNewData->complete_status = "0";
                $tvNewData->sell_id = $tvSellDataId;
                $tvNewData->pin = "init";
                $tvNewData->total_paid = $validatedData['initial_payment'];
                $tvNewData->save();
            
                DB::commit();
                
            } catch (\Exception $e) {
                DB::rollBack();
                // Handle the error, log it, or return a response to the user
                return redirect()->back()->with('error', 'Something went wrong');
            }
           
            
            $createdAtDate = new DateTime($tvSellData->created_at);

            $nextPayDate = $createdAtDate->modify('+1 month');
 
            $next_pay_date = $nextPayDate->format('Y-m-d');

            

             $data = [
                'Username' => 'walton_tv',
                'Password' => 'Dhaka@657871',
                'From' => '8801847505127',
                'To' => $tvSellData->customer_phone,
                'Message' => 'ওয়ালটন পরিবারে স্বাগতম।'. 'কিস্তির ডিটেলস জানুন: https://waltontvrni.com/emi-system/status/'. $validatedData['barcode'].'. For any query call '.Auth::user()->phone,
            ];
    
            try {
                // Send the request to the SMS API
                $response = Http::get('https://api.mobireach.com.bd/SendTextMultiMessage', $data);
    
                
            } catch (\Exception $e) {
                
            }

             $request->session()->flash('success', 'TV sell information submitted successfully!');
    
             return redirect()->back();
        }else{
            return redirect()->back()->with('error', 'The Barcode does not exist in the system');
        }
       }catch(\Exception $e){
           return redirect()->back()->with('error', 'Invalid state of data');
       }
        
        
       
       
    }


    public function checkBarcode(Request $request){

        $validatedData = $request->validate([
            'barcode' => 'required|string',
            'pass_key' => 'required|string',
        ]);

        $existingRecord = TvSellData::where('user_id', Auth::user()->id)
        ->where('barcode', $validatedData['barcode'])
        ->exists();

        if ($existingRecord) {
            // If a record exists in TvSellData, check if the pass_key and barcode exist in TvEmiData
            $existingEmiRecord = TvEmiData::where('pass_key', $validatedData['pass_key'].",".$validatedData['barcode'])
            ->where('barcode', $validatedData['barcode'])
            ->exists();

            if ($existingEmiRecord) {
                return redirect()->back()->with('error', 'Pass key Already used, try a new pass key');
            } else {
                $passKeyMatches = false;
            
                $systemData = TvSystemEmiData::where('barcode', $validatedData['barcode'])->first();

                $secureCodes =explode("*", $systemData->passkeys);

                foreach ($secureCodes as $secureCode) {
                    
                    if ($validatedData['pass_key'] == $secureCode) {
                        $passKeyMatches = true;
                        break;
                    }
                }
                
                if ($passKeyMatches) {

                    $tvSellData = TvSellData::where('barcode', $validatedData['barcode'])->first();
                    $barcode = $validatedData['barcode'];
                        
                    $records = TvEmiData::where('barcode', $barcode)->get();
                    
                    $totalAmount = $tvSellData->down_payment;

                    foreach ($records as $record) {
                        
                        $totalAmount += (int) $record->amount;
                    }
                    
                    return redirect()->back()->with('success', 'Secure codes generated successfully.')
                                                ->with('tvSellData', $tvSellData)                               
                                                ->with('records', $records)
                                                ->with('totalAmount', $totalAmount)
                                                ->with('passKey',$validatedData['pass_key'])
                                                ->with('due', (int) $tvSellData->total_amount - $totalAmount);
                } else {
                
                    return redirect()->back()->with('error', 'Pass key does not match.');
                }
            }   
        }
        else{
                return redirect()->back()->with('error', 'You are not authorized to generate Pin code for this Barcode');
        }

    }





    public function makePayment(Request $request){
        $validatedData = $request->validate([
            'amount' => 'required|numeric',
        ]);

        $secureCodes = [];
       
        $tvSystemEmiData = TvSystemEmiData::where('barcode', $request->barcode)->first();
        $macAddress = $tvSystemEmiData->mac;

        $secureCodes = explode("*", $tvSystemEmiData->pins);

         $nextSecureCode = "";
         $unusedPin=null;

         foreach ($secureCodes as $pin) {
            $existingEmiRecord1 = TvEmiData::where('pin_code', $pin)
                ->where('barcode', $request->barcode)
                ->exists();
            if (!$existingEmiRecord1) {
               
                // Found an unused passkey
                $unusedPin = $pin;
                break;
            }
        }
        $nextSecureCode = $unusedPin;

        $barcode = "";

        $tvSellData = TvSellData::where('barcode', $request->barcode)->first();
        $barcode = $request->barcode;
        
         $records = TvEmiData::where('barcode', $barcode)->get();
         $lastRecord = $records->last();
         $lastAmount=0;
         
         if($lastRecord){
           $amount = $lastRecord->amount;
           $lastPayDate = new DateTime($lastRecord->pay_date);

           $nextPayDate = $lastPayDate->modify('+1 month');

           $next_pay_date = $nextPayDate->format('Y-m-d');

       }else{
           $lastAmount = $tvSellData->down_payment;
           $createdAtDate = new DateTime($tvSellData->created_at);

           $nextPayDate = $createdAtDate->modify('+1 month');

           $next_pay_date = $nextPayDate->format('Y-m-d');
       }   

        if($lastAmount == 0 && $validatedData['amount'] == 0){
            return redirect()
            ->back()->with('error', 'পরপর দুইবার ০ এমাউন্ট পে করা যাবে না। ');
        }


         $totalAmount = $tvSellData->down_payment;

         foreach ($records as $record) {
             
             $totalAmount += (int) $record->amount;
         }

         $totalAmount += (int) $validatedData['amount'];
         $status="0";
         if($totalAmount == $tvSellData->total_amount){
            $nextSecureCode = end($secureCodes);
            $status="1";
         }

         if($totalAmount > $tvSellData->total_amount){
            return redirect()
            ->back()->with('error', 'Paid amount is invalid');
         }

         $currentDateFormatted = Carbon::now()->format('Y-m-d');

         $newRecord = TvEmiData::create([
            'barcode' => $barcode,
            'pay_date' => $currentDateFormatted,
            'sell_id' => $tvSellData->id,
            'amount' => $validatedData['amount'],
            'pass_key' => $request->passkey.",".$request->barcode,
            'pin_code' => $nextSecureCode,
            
        ]);

        $tvSystemEmiData = TvSystemEmiData::where('barcode', $barcode)->first();
        $tvSystemEmiData->status = "0";
        $tvSystemEmiData->save();

        $tvNewData = Tvdata::where('barcode', $barcode)->first();
        if($tvNewData){
            $tvNewData->pin = $nextSecureCode ?? "";
            $tvNewData->total_paid = $totalAmount;
            $tvNewData->complete_status = $status;
            $tvNewData->save();
        }

        $due= (int) $tvSellData->total_amount - $totalAmount;
        //Data to be sent to the API
         $data = [
            'Username' => 'walton_tv',
            'Password' => 'Dhaka@657871',
            'From' => '8801847505127',
            'To' => $tvSellData->customer_phone,
            'Message' => 'আপনার টিভির পিনকোড: ' . $nextSecureCode.", " . 'বিস্তারিত জানুন: https://waltontvrni.com/emi-system/status/'. $request->barcode,
        ];

        try {
            // Send the request to the SMS API
            $response = Http::get('https://api.mobireach.com.bd/SendTextMultiMessage', $data);

            
        } catch (\Exception $e) {
            
        }
        
         // Data to be sent to the API
        $data1 = [
            'Username' => 'walton_tv',
            'Password' => 'Dhaka@657871',
            'From' => '8801847505127',
            'To' => Auth::user()->phone,
            'Message' =>  "Name: ".$tvSellData->customer_name .', todays payment: '.$validatedData['amount'] .'taka, total Paid: '.$totalAmount. 'taka, due: '. $due . 'taka, next date: '. $next_pay_date,
        ];

        try {
            // Send the request to the SMS API
            $response = Http::get('https://api.mobireach.com.bd/SendTextMultiMessage', $data1);

            
        } catch (\Exception $e) {
            
        }
        

        return redirect()
        ->back()->with('success', 'Form submitted successfully.')
        ->with('newRecord', $newRecord)
        ->with('totalAmount',$totalAmount)
        ->with('price',$tvSellData->total_amount)
        ->with('due', (int) $tvSellData->total_amount - $totalAmount);


    }


    function generateSecureAlphanumeric($barcode,$macAddress,$digit) {
        $fixedSalt = env('FIXED_SALT');

        $combinedString = $barcode . $macAddress . $fixedSalt . $digit;

        $hashedString = hash('sha256', $combinedString);

        $result = strtoupper(substr($hashedString, 0, 8));

        return $result;
    }

    public static function generateSecureNumeric($inputString, $digit) {
        $fixedSalt = env('FIXED_SALT'); 
       
        $combinedString = $digit . $inputString . $fixedSalt;
        
        try {
            $hashedBytes = hash('sha256', $combinedString, true); 
            
            $number = self::bytesToDecimal($hashedBytes);
    
            $secureNumber = abs($number % 1000); 
    
            return sprintf("%03d", $secureNumber);
        } catch (Exception $e) {
            return null;
        }
    }
    
    private static function bytesToDecimal($bytes) {
        $result = 0;
        for ($i = 0; $i < strlen($bytes); $i++) {
          $byteValue = ord($bytes[$i]);
          $result = ($result << 8) + ($byteValue & 0xFF); 
        }
        // Check for overflow and adjust if necessary (similar to the provided Stack Overflow solution)
        return $result;
    }

    public static function updateStatus(Request $request, $id){
        
        $tvSellData = TvSystemEmiData::where('barcode', $id)->first();

        if ($tvSellData) {

            
            // Toggle the status
            $tvSellData->status = $tvSellData->status == "0" ? "1" : "0";
    
            // Save the changes
            $tvSellData->save();
    
            return redirect()->back()->with('success', 'Tv is locked now');
        } else {
             return redirect()->back()->with('error', 'Something went wrong');
        }
 

    }


    public static function updateLockStatus(Request $request, $id){
        
        $tvSellData = TvSystemEmiData::where('barcode', $id)->first();

        if ($tvSellData) {

            $tvSellData->status = "1";
   
            $tvSellData->save();
    
            return redirect()->back()->with('success', 'Tv is locked now');
        } else {
             return redirect()->back()->with('error', 'Something went wrong');
        }
 

    }


    public static function updateUnLockStatus(Request $request, $id){
        
        $tvSellData = TvSystemEmiData::where('barcode', $id)->first();

        if ($tvSellData) {

            $tvSellData->status = "0";
   
            $tvSellData->save();
    
            return redirect()->back()->with('success', 'Tv is locked now');
        } else {
             return redirect()->back()->with('error', 'Something went wrong');
        }
 

    }



    public static function paymentHistory($barcode) {
        // Fetch necessary data
        $data = TvSellData::where('barcode', $barcode)->first();
        $records = TvEmiData::where('barcode', $barcode)->get();
        $tvSystemEmiData = TvSystemEmiData::where('barcode', $barcode)->first();
        $lastRecord = $records->last();
        $totalAmount = $data->down_payment;
    
        // Calculate total amount paid
        foreach ($records as $record) {
            $totalAmount += (int) $record->amount;
        }
        
        // Attach total amount and system data to $data
        $data->total = $totalAmount;
        $data->system = $tvSystemEmiData;
    
        // Calculate next payment date
        if ($lastRecord) {
            $data->pin = $lastRecord->pin_code;
            $data->date = $lastRecord->pay_date;
            $lastPayDate = new DateTime($lastRecord->pay_date);
            $nextPayDate = $lastPayDate->modify('+1 month');
            $data->next_pay_date = $nextPayDate->format('Y-m-d');
        } else {
            $createdAtDate = new DateTime($data->created_at);
            $nextPayDate = $createdAtDate->modify('+1 month');
            $data->next_pay_date = $nextPayDate->format('Y-m-d');
        }   
    
        // Find an unused passkey and attach it to $data
        $unusedPasskey = null;
        if ($tvSystemEmiData) {
            $secureCodes = explode("*", $tvSystemEmiData->passkeys);
            foreach ($secureCodes as $passkey) {
                $existingEmiRecord = TvEmiData::where('pass_key', $passkey.','.$barcode)
                    ->where('barcode', $barcode)
                    ->exists();
                if (!$existingEmiRecord) {
                    // Found an unused passkey
                   
                    $unusedPasskey = $passkey;
                    break;
                }
            }
        }
    
        // Attach the found passkey to $data if available
        $data->passkey = $unusedPasskey;

        $unusedPin= null;
        if ($tvSystemEmiData) {
            $secureCodes = explode("*", $tvSystemEmiData->pins);
            
            foreach ($secureCodes as $pin) {
                $existingEmiRecord1 = TvEmiData::where('pin_code', $pin)
                    ->where('barcode', $barcode)
                    ->exists();
                if (!$existingEmiRecord1) {
                   
                    // Found an unused passkey
                    $unusedPin = $pin;
                    break;
                }
            }
            $data->pin = $unusedPin;
        }
        

    
        // Return the view with necessary data
        return view("seller.payment", compact('records', 'data'));
    }
    


    
    public function repairTvInfo(Request $request){
        $validatedData = $request->validate([
            'current_barcode' => 'required|string|max:255',
            'new_barcode' => 'required|string|max:255',
        ]);

        $tvSystemEmiData = TvSystemEmiData::where('barcode', $validatedData['current_barcode'])->first();

        if($tvSystemEmiData){

            try{
                DB::beginTransaction();

                $tvSellData = TvSellData::where('barcode', $validatedData['current_barcode'])->first();
                $tvData = TvData::where('barcode', $validatedData['current_barcode'])->first();

                $tvRepairData = new RepairTv();
                $tvRepairData->plaza_id =  Auth::user()->id;
                $tvRepairData->sell_id = $tvSellData->id;
                $tvRepairData->sr_number = $request->sr_number;
                $tvRepairData->current_barcode = $validatedData['current_barcode'];
                $tvRepairData->new_barcode = $validatedData['new_barcode'];    
                $tvRepairData->save();
    
                $tvSystemBackData = new TvOldData();
                $tvSystemBackData->barcode= $tvSystemEmiData->barcode;
                $tvSystemBackData->mac=$tvSystemEmiData->mac;
                $tvSystemBackData->pins=$tvSystemEmiData->pins;
                $tvSystemBackData->total_paid = $tvData->total_paid;
                $tvSystemBackData->passkeys=$tvSystemEmiData->passkeys;
                $tvSystemBackData->status=$tvSystemEmiData->status;    
                $tvSystemBackData->save();

                $tvEmi =TvEmiData::where('barcode', $validatedData['current_barcode'])->get();

                foreach($tvEmi as $data){
                   
                    $existingEmiData = TvOldEmiData::where('pin_code', $data->pin_code)->first();
                    if (!$existingEmiData) {
                        TvOldEmiData::create([
                            'barcode' => $data->barcode,
                            'pay_date' => $data->pay_date,
                            'sell_id' => $data->sell_id,
                            'amount' => $data->amount,
                            'pass_key' => $data->pass_key,
                            'pin_code' => $data->pin_code,
                        ]);
                    }
                }
    
                //update all the table barcode
                $tvSellData->barcode = $validatedData['new_barcode'];
                $tvSellData->save();
    
                TvEmiData::where('barcode', $validatedData['current_barcode'])->update(['barcode' =>  $validatedData['new_barcode']]);
                Tvdata::where('barcode', $validatedData['current_barcode'])->update(['barcode' =>  $validatedData['new_barcode']]);
        
                DB::commit();

            }catch (\Exception $e) {
                DB::rollBack();
                // Handle the error, log it, or return a response to the user
                return redirect()->back()->with('error', $e->message);
            }

           
             $request->session()->flash('success', 'TV sell information submitted successfully!');
    
             return redirect()->back();
        }else{
            return redirect()->back()->with('error', 'Old Barcode information is not valid');
        }
       
       

    }


    public function repairTV(Request $request,$barcode){
        return view('seller.repair_tv',compact('barcode'));
    }



    public function sendActivationCode($mobile, $activateCode)
    {
        // Data to be sent to the API
        $data = [
            'Username' => 'walton_tv',
            'Password' => 'Dhaka@657871',
            'From' => '8801847505127',
            'To' => $mobile,
            'Message' => 'Your TV activation pin code is ' . $activateCode,
        ];

        try {
            // Send the request to the SMS API
            $response = Http::get('https://api.mobireach.com.bd/SendTextMultiMessage', $data);

            if ($response->successful()) {
                // Handle successful response
                return redirect()
                    ->back()
                    ->with('success', 'Code successfully sent');
            } else {
                // Log the error details for debugging
                \Log::error('Failed to send SMS', ['response' => $response->body()]);
                return redirect()
                    ->back()
                    ->with('error', 'Failed to send the code');
            }
        } catch (\Exception $e) {
            // Handle any exceptions that occur during the HTTP request
            \Log::error('Exception occurred while sending SMS', ['exception' => $e]);
            return redirect()
                ->back()
                ->with('error', 'An error occurred while sending the code');
        }
    }

    public function generatePDF(Request $request){
    
        $query = TvSellData::where('user_id', Auth::user()->id);

        if ($request->has('filter')) {
            switch ($request->filter) {
                case 'today':
                    $query->whereDate('created_at', today());
                    break;
                case 'this_month':
                    $query->whereMonth('created_at', now()->month);
                    break;
                case 'last_six_months':
                    $query->whereBetween('created_at', [now()->subMonths(5), now()]);
                    break;
                case 'this_year':
                    $query->whereYear('created_at', now()->year);
                    break;
                case 'custom_range':
                    $query->whereBetween('created_at', [$request->start_date, $request->end_date]);
                    break;
                default:
                    break;
            }
        }
    
        $tvSellData = $query->latest()->get();
        $tvSellData->user= Auth::user();

        foreach ($tvSellData as $data) {
            
            $tvSystemEmiData = TvSystemEmiData::where('barcode', $data->barcode)->first();

            $records = TvEmiData::where('barcode', $data->barcode)->get();
            $lastRecord = $records->last();
            $totalAmount = $data->down_payment;
   
            foreach ($records as $record) {
            
                $totalAmount += (int) $record->amount;
            }
            $data->total = $totalAmount; 
            $data->system = $tvSystemEmiData;
           

            if($lastRecord){
                 $data->pin = $lastRecord->pin_code;
                 $data->date = $lastRecord->pay_date;

                $lastPayDate = new DateTime($lastRecord->pay_date);

                $nextPayDate = $lastPayDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');

            }else{
                
                $createdAtDate = new DateTime($data->created_at);

                $nextPayDate = $createdAtDate->modify('+1 month');

                $data->next_pay_date = $nextPayDate->format('Y-m-d');
            }   
        }

          $pdf = PDF::loadView('seller.reports.overview',compact('tvSellData'));
          return $pdf->download('sales_report.pdf');
        //return view('seller.reports.overview',compact('tvSellData'));
    

    }

    public function exportToExcel(Request $request)
    {
        $filter = $request->input('filter', 'all_record');
        return Excel::download(new SalesReportExport($filter), 'sales_report.xlsx');
    }


}
