<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\TvSystemEmiData;
use App\Models\ProductionTvData;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Config;
use App\Models\TvSellData;
use App\Models\TvEmiData;
use App\Models\User;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Carbon;
use DateTime;
use Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class TvSystemEmiDataController extends Controller
{
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'barcode' => 'required|string',
            'mac_address' => 'required|string',
            'duration' => 'required|string',
        ]);
    
        // Attempt to find a record with the given barcode
        $tvSystemEmiData = TvSystemEmiData::firstOrNew(['barcode' => $validatedData['barcode']]);
    
        // Update or set the attributes
        $tvSystemEmiData->mac_address = $validatedData['mac_address'];
        $tvSystemEmiData->duration = $validatedData['duration'];
    
        // Save the record
        $tvSystemEmiData->save();
    
        return response()->json(['message' => 'Data inserted successfully'], 201);
    }

    public function barView(){
        return  view('checkbar');
    }

    public function tvEntry(){
        return view('production');
    }

    public function userView($barcode){
        
          // Fetch necessary data
          $data = TvSellData::where('barcode', $barcode)->first();
          $records = TvEmiData::where('barcode', $barcode)->get();
          $tvSystemEmiData = TvSystemEmiData::where('barcode', $barcode)->first();
          $lastRecord = $records->last();
          $totalAmount = $data->down_payment;
      
          // Calculate total amount paid
          foreach ($records as $record) {
              $totalAmount += (int) $record->amount;
          }
          
          // Attach total amount and system data to $data
          $data->total = $totalAmount;
          $data->system = $tvSystemEmiData;
          $data->records = $records;
          //$data->seller = Auth::user()->phone;
          // Calculate next payment date
          if ($lastRecord) {
              $data->pin = $lastRecord->pin_code;
              $data->date = $lastRecord->pay_date;
              $lastPayDate = new DateTime($lastRecord->pay_date);
              $nextPayDate = $lastPayDate->modify('+1 month');
              $data->next_pay_date = $nextPayDate->format('Y-m-d');
          } else {
              $createdAtDate = new DateTime($data->created_at);
              $nextPayDate = $createdAtDate->modify('+1 month');
              $data->next_pay_date = $nextPayDate->format('Y-m-d');
          }   
      
         
        return view('userview',compact('data'));
    }


    public function tvEntrySubmit(Request $request){
        $validatedData = $request->validate([
           
            'barcode' => ['required', 'string', 'max:255', 'regex:/^[WM][a-zA-Z0-9]{13}$/i'],
            'security' => ['required', 'string', 'regex:/^s.{5}$/i'],
            
        ]);


        try{

            $tvSystemEmiData = TvSystemEmiData::where('barcode', $validatedData['barcode'])->first();

            if($tvSystemEmiData){
                $prodData = new ProductionTvData();
                $prodData->barcode = $validatedData['barcode'];
                $prodData->security_code = $validatedData['security'];
                $prodData->save();

                return redirect()
                ->back()->with('success', 'Data saved successfully.');
            }else{
                return redirect()->back()->with('error', 'Barcode not saved in production line.');
            }

            
        }catch(\Exception $e){
            return redirect()->back()->with('error', $e->getMessage());
        }


    }


    public function barCheck(Request $request){
        $validatedData = $request->validate([
            'barcode' => 'required|string',
        ]);

        $tvSystemEmiData = TvSystemEmiData::where('barcode', $validatedData['barcode'])->first();

        if($tvSystemEmiData){
            $request->session()->flash('success', 'TV Barcode Found in the system');
    
            return redirect()->back();
        }else{
            return redirect()->back()->with('error', 'Barcode Not found in the system');
        }


    }

    public function switchLang($lang)
    {
       
        if (array_key_exists($lang, Config::get('language'))) { 
           
            Session::put('applocale', $lang);

            return redirect()->back();
        }
        
    }

    public function requestReset(Request $request)
    {
       // dd($request->phone);
        $validator = Validator::make($request->all(), [
            'phone' => 'required|exists:users,phone',
        ]);
    
        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 422);
        }
    
        $phone = $request->phone;
        $user = User::where('phone', $phone)->first();
    
        $token = Str::random(6); // Generating a 6-digit token
    
        // Save token in database with created_at timestamp
        DB::table('password_resets')->updateOrInsert(
            ['phone' => $phone],
            ['token' => $token, 'created_at' => now()]
        );
    
        // Send the token via SMS (not shown here)
                     $data = [
                'Username' => 'walton_tv',
                'Password' => 'Dhaka@657871',
                'From' => '8801847505127',
                'To' => $phone,
                'Message' => 'Your password reset token is: '.$token
            ];
    
            try {
                // Send the request to the SMS API
                $response = Http::get('https://api.mobireach.com.bd/SendTextMultiMessage', $data);
            if ($response->successful()) {
                return redirect()->route('password.reset.form')->with('status', 'Reset token sent to your phone.');
            } else {
                // Handle failed SMS sending
                return redirect()->back()->with('error', 'Failed to send reset token. Please try again.');
            }
                
            } catch (\Exception $e) {
                return redirect()->back()->with('error', 'An error occurred while sending the reset token.');
            }
    
        // response()->json(['message' => 'Reset token sent to your phone.']);
    }
    
    
    public function resetPassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'phone' => 'required|exists:users,phone',
            'token' => 'required',
            'password' => 'required|confirmed|min:8',
        ]);
    
        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 422);
        }
    
        $phone = $request->phone;
        $token = $request->token;
    
        // Validate the token
        $passwordReset = DB::table('password_resets')->where('phone', $phone)->first();
    
        if (!$passwordReset) {
            return response()->json(['error' => 'Invalid token.'], 400);
        }
    
        // Check if the token has expired (30 minutes)
        $tokenCreatedAt = Carbon::parse($passwordReset->created_at);
        if ($tokenCreatedAt->addMinutes(30)->isPast()) {
            // Token has expired, delete it from the database
            DB::table('password_resets')->where('phone', $phone)->delete();
            return response()->json(['error' => 'Token has expired.'], 400);
        }
    
        // Token is valid, proceed with password reset
        $user = User::where('phone', $phone)->first();
        $user->password = Hash::make($request->password);
        $user->save();
    
        // Optionally, delete the token after successful reset
        DB::table('password_resets')->where('phone', $phone)->delete();
    
        return redirect()->route('login')->with('status', 'Password updated successfully');
    }
    


}
