<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>TV Production</title>
  <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
  <style>
    body {
      background-color: #e0f7fa; /* Light cyan background */
      font-family: 'Arial', sans-serif;
    }
    .login-container {
      max-width: 800px;
      margin: 100px auto;
      padding: 40px;
      background-color: #ffffff;
      border-radius: 10px;
      box-shadow: 0 0 20px rgba(0, 0, 0, 0.1);
    }
    .login-container h2 {
      margin-bottom: 30px;
      text-align: center;
      color: #007c91;
      font-family: 'Roboto', sans-serif;
    }
    .login-container form .form-control {
      border-radius: 4px;
      border: 1px solid #00acc1;
    }
    .login-container form .btn-primary {
      border-radius: 4px;
      width: 100%;
      background-color: #00acc1;
      border-color: #00acc1;
      transition: background-color 0.3s, border-color 0.3s;
    }
    .login-container form .btn-primary:hover {
      background-color: #007c91;
      border-color: #007c91;
    }
    .login-container .signup-link {
      text-align: center;
      margin-top: 20px;
    }
    .error-message {
      color: #dc3545;
      margin-top: 10px;
    }
    .alert-success, .alert-danger {
      margin-top: 20px;
    }
    .alert-success {
      color: #155724;
      background-color: #d4edda;
      border-color: #c3e6cb;
    }
    .alert-danger {
      color: #721c24;
      background-color: #f8d7da;
      border-color: #f5c6cb;
    }
  </style>
</head>
<body>
  <div class="login-container">
    <h2>Barcode & Security Code Entry</h2>
    <form action="{{ route('production.tv.entry.submit') }}" method="POST">
        @csrf
        <div class="form-group">
            <input type="text" class="form-control" id="barcode" name="barcode" placeholder="Enter Barcode" required maxlength="14" autofocus>
        </div>
        <div class="form-group">
            <input type="text" class="form-control" id="security" name="security" placeholder="Security Key" required maxlength="6">
        </div>
        @if ($errors->any())
            <div class="error-message">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif
        <button type="submit" class="btn btn-primary">Submit</button>
    </form>
    @if (session('success'))
        <div class="alert alert-success alert-dismissible fade show mt-2" role="alert">
            {{ session('success') }}
        </div>
    @endif
    @if (session('error'))
        <div class="alert alert-danger mt-2">
            {{ session('error') }}
        </div>
    @endif
  </div>

  <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
  <script>
    document.addEventListener('DOMContentLoaded', function () {
        const barcodeInput = document.getElementById('barcode');
        const securityInput = document.getElementById('security');
        const form = barcodeInput.closest('form');

        function validateAndSubmit() {
            if (/^[WM][a-zA-Z0-9]{13}$/i.test(barcodeInput.value) && /^s.{5}$/i.test(securityInput.value)) {
                form.submit();
                setTimeout(() => barcodeInput.focus(), 500); // Set focus back to barcode field after submission
            }
        }

        // Set initial focus
        if (barcodeInput.value === '') {
            barcodeInput.focus();
        } else {
            securityInput.focus();
        }
        
        

        // Event listener for barcode input
        barcodeInput.addEventListener('input', function (event) {
            let value = event.target.value;
            if (value.length > 14) {
                event.target.value = value.slice(0, 14);
                return;
            }
            if (value.length === 14) {
                securityInput.focus();
            }
            if (/^s/i.test(value)) {
                securityInput.focus();
                securityInput.value = value;
                event.target.value = '';
            }
            if (!/^w|m/i.test(value) && value.length > 0) {
                event.target.value = '';
            }
            validateAndSubmit();
        });

        // Event listener for security input
        securityInput.addEventListener('input', function (event) {
            let value = event.target.value;
            if (value.length > 6) {
                event.target.value = value.slice(0, 6);
                return;
            }
            if (value.length === 6) {
                if (barcodeInput.value === '') {
                    barcodeInput.focus();
                } else {
                    validateAndSubmit();
                }
            }
            if (/^w|m/i.test(value)) {
                barcodeInput.focus();
                barcodeInput.value = value;
                event.target.value = '';
            }
            if (!/^s/i.test(value) && value.length > 0) {
                event.target.value = '';
            }
        });
    });
  </script>
  <script>
    setTimeout(function(){
        $('.alert').fadeOut('slow');
        barcodeInput.focus();
    }, 7000); // 5000 milliseconds = 5 seconds
  </script>
</body>
</html>
