<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Backend\AdminController;
use App\Http\Controllers\Backend\DashboardController;
use App\Http\Controllers\Service\ServiceController;
use App\Http\Controllers\Service\DashboardController as ServiceDashboardController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});



// Admin routes
Route::get('login/admin',[AdminController::class,'adminLoginForm'])->name('admin.login.form');
Route::post('admin-login',[AdminController::class,'adminLogin'])->name('admin.login');



Route::group(['middleware' => 'admin'], function(){
    Route::get('admin/dashboard',[DashboardController::class,'adminDashboard'])->name('admin.dashboard');
    Route::get('admin/logout',[DashboardController::class,'adminLogout'])->name('admin.logout');
    Route::get('admin/plaza', [AdminController::class,'plaza'])->name('admin.plaza');
    Route::get('/plaza-details/{id}', [AdminController::class, 'plazaDetails'])->name('admin.plaza.view');
    Route::get('admin/tv-payment-history/{barcode}', [AdminController::class, 'paymentAdminHistory'])->name('tv.admin.payment.history');
    
});

//Service routes
Route::get('login/service',[ServiceController::class,'serviceLoginForm'])->name('service.login.form');
Route::post('service-login',[ServiceController::class,'serviceLogin'])->name('service.login');



Route::group(['middleware' => 'service'], function(){
    Route::get('service/dashboard',[ServiceDashboardController::class,'serviceDashboard'])->name('service.dashboard');
    Route::get('service/records',[ServiceDashboardController::class,'serviceRecords'])->name('service.records');
    Route::get('service/logout',[ServiceDashboardController::class,'serviceLogout'])->name('service.logout');

    Route::post('status-tv-submit', [ServiceDashboardController::class, 'statusTvInfo'])->name('tv.status.submit');
    
});



Route::post('/register', [App\Http\Controllers\Auth\RegisterController::class, 'register'])->middleware('admin');

Auth::routes();

Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

Route::get('status/{barcode?}', [App\Http\Controllers\TvSystemEmiDataController::class,'userView'])->name('user.view');

Route::post('barcode-check',[App\Http\Controllers\TvSystemEmiDataController::class, 'barCheck'])->name('barCheck.submit');

Route::get('tv-status',[ServiceDashboardController::class,'serviceTvStatus'])->name('service.tv.status');
Route::get('barcode-review',[App\Http\Controllers\TvSystemEmiDataController::class, 'barView']);
Route::get('lang/{lang?}',[App\Http\Controllers\TvSystemEmiDataController::class, 'switchLang'])->name('lang.switch');

Route::get('generate-pdf/{filter?}', [App\Http\Controllers\HomeController::class, 'generatePDF'])->name('generate-pdf');
Route::get('exportToExcel/{filter?}', [App\Http\Controllers\HomeController::class, 'exportToExcel'])->name('exportToExcel');

Route::get('tv-production',[App\Http\Controllers\TvSystemEmiDataController::class,'tvEntry'])->name('production.tv.entry');
Route::post('tv-production-submit',[App\Http\Controllers\TvSystemEmiDataController::class,'tvEntrySubmit'])->name('production.tv.entry.submit');


Route::get('change-password', [App\Http\Controllers\HomeController::class, 'showChangePasswordForm'])->name('change-password.form');
Route::post('change-password', [App\Http\Controllers\HomeController::class, 'changePassword'])->name('change-password');

Route::get('password/reset-request', function () {
    return view('auth.forgot-request');
})->name('password.request');

Route::post('password/reset-request', [App\Http\Controllers\TvSystemEmiDataController::class, 'requestReset'])->name('password.reset.request');


Route::get('password/reset', function () {
    return view('auth.forgot-password');
})->name('password.reset.form');

Route::post('password/reset', [App\Http\Controllers\TvSystemEmiDataController::class, 'resetPassword'])->name('password.reset');





Route::group(['middleware' => 'auth'], function () {
    Route::get('/search', [App\Http\Controllers\HomeController::class, 'search'])->name('search');
    Route::get('/new-tv', [App\Http\Controllers\HomeController::class, 'newTv'])->name('newTv');
    Route::post('/submit-tv-sell', [App\Http\Controllers\HomeController::class, 'sellTvData'])->name('tv.sell.submit');
    Route::get('/barcode-check/{barcode?}', [App\Http\Controllers\HomeController::class, 'barcodeCheck'])->name('barcodeCheck');
    Route::get('/records', [App\Http\Controllers\HomeController::class, 'sellRecords'])->name('sellRecords');
    Route::get('/due-records', [App\Http\Controllers\HomeController::class, 'dueSellRecords'])->name('dueSellRecords');
    Route::post('/submit-bar-check', [App\Http\Controllers\HomeController::class, 'checkBarcode'])->name('tv.barcode.submit');
    Route::post('/make-payment', [App\Http\Controllers\HomeController::class, 'makePayment'])->name('tv.payment.submit');
    Route::post('/update-status/{id}', [App\Http\Controllers\HomeController::class, 'updateStatus'])->name('tv.update.status');

    Route::post('/update-status-lock/{id}', [App\Http\Controllers\HomeController::class, 'updateStatus'])->name('tv.update.status.lock');
    Route::post('/update-status-unlock/{id}', [App\Http\Controllers\HomeController::class, 'updateUnLockStatus'])->name('tv.update.status.unlock');

    Route::get('/payment-history/{barcode}', [App\Http\Controllers\HomeController::class, 'paymentHistory'])->name('tv.payment.history');
    Route::get('/regular-payment/{barcode?}',[App\Http\Controllers\HomeController::class, 'regularPayment'])->name('tv.regular.payment');
    Route::post('/submit-regular-barcheck', [App\Http\Controllers\HomeController::class, 'regularBarcodeCheck'])->name('tv.barcode.regular.submit');
   /* Route::get('/repair/{barcode?}',[App\Http\Controllers\HomeController::class,'repairTV'])->name('tv-repair');
    Route::post('/repair-tv-submit', [App\Http\Controllers\HomeController::class, 'repairTvInfo'])->name('tv.repair.submit');*/
    
});


